@@ -94,7 +94,12 @@ parse_g.add_argument(
     "--cppcheck", dest="cppcheck", action="store_true", help="Install cppcheck"
 )
 parse_g.add_argument("--gcovr", dest="gcovr", action="store_true", help="Install gcovr")
-parse_g.add_argument("--tfel", dest="tfel", action="store_true", help="Install tfel")
+parse_g.add_argument(
+    "--mfront",
+    dest="mfront",
+    action="store_true",
+    help="Install tfel and build OGS with -DOGS_USE_MFRONT=ON",
+)
 parse_g.add_argument(
     "--insitu",
     dest="insitu",
@@ -271,7 +276,9 @@ if local_args.ogs != "clean":
     elif local_args.pm == "system":
         Stage0 += cmake(eula=True, version="3.19.4")
         Stage0 += boost(
-            version=versions["minimum_version"]["boost"], bootstrap_opts=["headers"]
+            version=versions["minimum_version"]["boost"],
+            bootstrap_opts=["--with-toolset=clang"] if toolchain.CC == "clang" else [],
+            b2_opts=["headers"],
         )
         Stage0 += environment(variables={"BOOST_ROOT": "/usr/local/boost"})
         Stage0 += packages(apt=["libxml2-dev"], yum=["libxml2-devel"])
@@ -375,7 +382,7 @@ if local_args.ogs != "clean":
                         "-DModule_vtkParallelMPI=ON",
                     ]
                 )
-            vtk_version = versions["tested_version"]["vtk"]
+            vtk_version = versions["minimum_version"]["vtk"]
             Stage0 += generic_cmake(
                 cmake_opts=vtk_cmake_args,
                 devel_environment={"VTK_ROOT": "/usr/local/vtk"},
@@ -456,7 +463,7 @@ if local_args.dev:
         ospackages=["neovim", "gdb", "silversearcher-ag", "ssh-client", "less"]
     )
 
-if local_args.tfel:
+if local_args.mfront:
     Stage0 += generic_cmake(
         directory="tfel-TFEL-3.3.0",
         ldconfig=True,
@@ -464,6 +471,7 @@ if local_args.tfel:
         prefix="/usr/local/tfel",
     )
     Stage0 += environment(variables={"TFELHOME": "/usr/local/tfel"})
+    cmake_args.append("-DOGS_USE_MFRONT=ON")
 
 if local_args.mkl:
     Stage0 += mkl(eula=True)
